﻿using GenLib;
using GenLib.Data;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using System;

namespace DocsGenTest.Unit
{
    [TestClass]
    public class GeneratorTest
    {
        [TestMethod]
        [DataRow("..\\..\\test_data\\example_input_data_correct_1.json", "${spis.soud.nazev}", "Okresní soud Plzeň - město")]
        [DataRow("..\\..\\test_data\\example_input_data_correct_1.json", "#foreach($variable in $spis.ucastnici) ${variable.prijmeni}#end", "Haasová Barelský ")]
        [DataRow("..\\..\\test_data\\example_input_data_correct_1.json", "${spis.datumVlozeni.datum.formatDate(\"dd.MM.yyyy\")}", "29.10.2021")]
        public void Generate_CorrectlyGenerated_True(string inputDataFile, string inputText, string expectedGeneratedText)
        {
            DataLoader loader = new DataLoader(inputDataFile);
            loader.LoadDataJson();

            string currentGeneratedText = Generator.Instance.Generate(inputText, loader.Root);

            Assert.AreEqual(expectedGeneratedText, currentGeneratedText);
        }

        [TestMethod]
        [DataRow("..\\..\\test_data\\example_input_data_correct_1.json", "${currentDate()}", null)]
        [DataRow("..\\..\\test_data\\example_input_data_correct_1.json", "${currentDate().formatDate(\"dd. MMMM yyyy\")}", "dd. MMMM yyyy")]
        public void Generate_CorrectlyGeneratedCurrentDate_True(string inputDataFile, string inputText, string dateFormat)
        {
            DataLoader loader = new DataLoader(inputDataFile);
            loader.LoadDataJson();

            string currentGeneratedText = Generator.Instance.Generate(inputText, loader.Root);

            if (dateFormat == null)
            {
                dateFormat = "dd.MM.yyyy";
            }

            string expectedGeneratedText = DateTime.Now.ToString(dateFormat);

            Assert.AreEqual(expectedGeneratedText, currentGeneratedText);
        }

        [TestMethod]
        [DataRow("..\\..\\test_data\\example_input_data_correct_1.json", "${spis.soud.nazev")]
        [DataRow("..\\..\\test_data\\example_input_data_correct_1.json", "#foreach($variable in $spis.ucastnici) ${variable.prijmeni}")]
        [ExpectedException(typeof(AntlrSyntaxException))]
        public void Generate_IncorrectGeneration_AntlrSyntaxException(string inputDataFile, string inputText)
        {
            DataLoader loader = new DataLoader(inputDataFile);
            loader.LoadDataJson();

            Generator.Instance.Generate(inputText, loader.Root);
        }

        [TestMethod]
        [DataRow("..\\..\\test_data\\example_input_data_correct_1.json", "${spis.datumVlozeni.datum.formatDate(\"xyz\")}")]
        [DataRow("..\\..\\test_data\\example_input_data_correct_1.json", "${currentDate().formatDate(\"xyz\")}")]
        [ExpectedException(typeof(DateTimeFormatException))]
        public void Generate_IncorrectGeneration_DateTimeFormatException(string inputDataFile, string inputText)
        {
            DataLoader loader = new DataLoader(inputDataFile);
            loader.LoadDataJson();

            Generator.Instance.Generate(inputText, loader.Root);
        }
    }
}
