﻿using GenLib.Data;
using GenLib.Document;
using GenLib.Entity;

namespace GenLib.Builder
{
    /// <summary>
    /// This class is Builder class for ForeachDirective entity.
    /// It provides to going through the parsing tree.
    /// </summary>
    class ForeachDirectiveBuilder : Builder
    {
        /// <summary>
        /// This property contains ForeachDirective entity.
        /// </summary>
        public ForeachDirective ForeachDirective { get; set; }

        /// <summary>
        /// Constructor of the ForeachDirectiveBuilder class.
        /// </summary>
        /// <param name="foreachDirective">ForeachDirective entity.</param>
        public ForeachDirectiveBuilder(ForeachDirective foreachDirective)
        {
            ForeachDirective = foreachDirective;
        }

        /// <summary>
        /// This method processes ForeachDirective entity.
        /// It inserts output values of foreach directive into the final document
        /// and adds these values into the final text of generated document.
        /// </summary>
        public void Build()
        {
            ControllingVariable controllingVariable = null;
            ForeachDirective.Block.controllingVariables.TryGetValue(ForeachDirective.ControlVariableId.Identificator, out controllingVariable);

            if (controllingVariable == null)
            {
                throw new CustomSyntaxException(ErrorType.CONTROLLING_VARIABLE_FE_NOT_FOUND);
            }

            DataObject controllingArrayValue = DirectiveUtil.ResolveDataObject(DataRoot, ForeachDirective.ControlArray, ControllingVariables);

            for (int i = controllingArrayValue.Descendants.Count - 1; i >= 0; i--)
            {
                DataObject currentDataObject = controllingArrayValue.Descendants[i];

                controllingVariable.DataObject = currentDataObject;

                DocumentManager.Instance.AddWordRange(ForeachDirective.ElementRange);
                DocumentManager.Instance.AddWordRange(ForeachDirective.Block.ElementRange);

                new BlockBuilder(ForeachDirective.Block).Build();

                Microsoft.Office.Interop.Word.Range elementRange = ForeachDirective.Block.ElementRange.Range;

                if (elementRange != null)
                {
                    if (i == controllingArrayValue.Descendants.Count - 1)
                    {
                        elementRange.End -= 1;
                        DocumentManager.Instance.CopyRange(elementRange, ForeachDirective.ElementRange.Range.End);
                        elementRange.End += 1;
                    }
                    else
                    {
                        DocumentManager.Instance.CopyRange(elementRange, ForeachDirective.ElementRange.Range.End);
                    }

                    DocumentManager.Instance.DeleteRange(ForeachDirective.ElementRange.Range);

                    if (i != 0)
                    {
                        DocumentManager.Instance.CopyRangeFromTemplate(ForeachDirective.ElementRange, ForeachDirective.ElementRange.Start);
                    }
                }
            }
        }
    }
}