﻿using GenLib.Entity.Enum;

namespace GenLib.Entity
{
    /// <summary>
    /// ForeachDirective entity. It relates with 'foreach_directive' rule in the grammar.
    /// </summary>
    class ForeachDirective : Directive
    {
        /// <summary>
        /// This property contains controlling variable of the current foreach directive.
        /// </summary>
        public Variable ControlVariableId { get; set; }

        /// <summary>
        /// This property contains controlling array of the current foreach directive.
        /// </summary>
        public Variable ControlArray { get; set; }

        /// <summary>
        /// This property contains block of code in the body of the foreach directive.
        /// </summary>
        public Block Block { get; set; }

        /// <summary>
        /// Constructor of the ForeachDirective class.
        /// </summary>
        /// <param name="controlVariableId">Controlling variable of the current foreach directive.</param>
        /// <param name="controlArray">Controlling array of the current foreach directive.</param>
        /// <param name="block">Block of code in the body of the foreach directive.</param>
        public ForeachDirective(Variable controlVariableId, Variable controlArray, Block block)
        {
            ControlVariableId = controlVariableId;
            ControlArray = controlArray;
            Block = block;
            DirectiveType = EDirectiveType.FOREACH;
        }

    }
}
