﻿using GenLib.Entity.Enum;

namespace GenLib.Entity
{
    /// <summary>
    /// TableForeachDirective entity. It relates with 'tableforeach_directive' rule in the grammar.
    /// </summary>
    public class TableForeachDirective : Directive
    {
        /// <summary>
        /// This property contains controlling variable of the current talbeforeach directive.
        /// </summary>
        public Variable ControlVariableId { get; set; }

        /// <summary>
        /// This property contains controlling array of the current tableforeach directive.
        /// </summary>
        public Variable ControlArray { get; set; }

        /// <summary>
        /// This property contains block of code in the body of the tableforeach directive.
        /// </summary>
        public Block Block { get; set; }

        /// <summary>
        /// Constructor of the TableForeachDirective class.
        /// </summary>
        /// <param name="controlVariableId">Controlling variable of the current tableforeach directive.</param>
        /// <param name="controlArray">Controlling array of the current tableforeach directive.</param>
        /// <param name="block">Block of code in the body of the tableforeach directive.</param>
        public TableForeachDirective(Variable controlVariableId, Variable controlArray, Block block)
        {
            ControlVariableId = controlVariableId;
            ControlArray = controlArray;
            Block = block;
            DirectiveType = EDirectiveType.TABLE_FOREACH;
        }
    }
}
