﻿namespace GenLib.Entity
{
    /// <summary>
    /// PropertyOrMethod entity. It relates with 'property_or_method' rule in the grammar.
    /// </summary>
    public class PropertyOrMethod
    {
        /// <summary>
        /// This property contains name of the propery or method.
        /// </summary>
        public string Name { get; set; }

        /// <summary>
        /// This property contains flag: true - if current entity is method; false - otherwise.
        /// </summary>
        public bool IsMethod { get; set; }

        /// <summary>
        /// This property contains parameter of current method.
        /// </summary>
        public Parameter Parameter { get; set; }

        /// <summary>
        /// Constructor of the PropertyOrMethod class.
        /// </summary>
        /// <param name="name">Name of the property or method.</param>
        public PropertyOrMethod(string name)
        {
            Name = name;
            IsMethod = false;
        }

        /// <summary>
        /// Constructor of the PropertyOrMethod class.
        /// </summary>
        /// <param name="name">Name of the property or method.</param>
        /// <param name="isMethod">Flag: true - if current entity is method; false - otherwise.</param>
        public PropertyOrMethod(string name, bool isMethod)
        {
            Name = name;
            IsMethod = isMethod;
        }

        /// <summary>
        /// Constructor of the PropertyOrMethod class.
        /// </summary>
        /// <param name="name">Name of the property or method.</param>
        /// <param name="parameter">Parameter of current method.</param>
        public PropertyOrMethod(string name, Parameter parameter)
        {
            Name = name;
            IsMethod = true;
            Parameter = parameter;
        }
    }
}
