﻿using Antlr4.Runtime.Misc;
using System.Collections.Generic;

namespace GenLib.Entity
{
    /// <summary>
    /// Variable entity. It relates with 'variable' rule in the grammar.
    /// </summary>
    public class Variable : Atom
    {
        /// <summary>
        /// This property contains identifier of the current variable.
        /// </summary>
        public string Identificator { get; set; }

        /// <summary>
        /// This property contains list of properties or methods related with the current variable.
        /// </summary>
        public List<PropertyOrMethod> PropertyOrMethodList { get; set; } = null;

        /// <summary>
        /// Constructor of the Variable class.
        /// </summary>
        /// <param name="ident">Identifier of the current variable.</param>
        public Variable(string ident)
        {
            Identificator = ident;
            PropertyOrMethodList = new ArrayList<PropertyOrMethod>();
            Type = EAtomType.VARIABLE;
        }

        /// <summary>
        /// This method composes language construction of the variable with its properties and methods.
        /// </summary>
        /// <returns>Language construction of the variable with its properties and methods.</returns>
        public override string ToString()
        {
            string properties = string.Empty;

            foreach(PropertyOrMethod currentProperty in PropertyOrMethodList)
            {
                if (currentProperty.IsMethod)
                {
                    break;
                }

                properties += "." + currentProperty.Name;
            }

            return Identificator + properties;
        }
    }
}
