﻿using System;

namespace GenLib
{
    /// <summary>
    /// This class represents syntax exceptions not included in AntlrSyntaxException.
    /// </summary>
    [Serializable]
    public class CustomSyntaxException : Exception
    {
        /// <summary>
        /// Prefix for syntax errors.
        /// </summary>
        private static readonly string SYNTAX_ERROR_TXT = "SYNTAX ERROR: ";

        /// <summary>
        /// Constructor of the CustomSyntaxException class.
        /// </summary>
        public CustomSyntaxException() : base() { }

        /// <summary>
        /// Constructor of the CustomSyntaxException class.
        /// </summary>
        /// <param name="message">Error message.</param>
        public CustomSyntaxException(string message) : base(SYNTAX_ERROR_TXT + message) { }

        /// <summary>
        /// Constructor of the CustomSyntaxException class.
        /// </summary>
        /// <param name="message">Error message.</param>
        /// <param name="inner">Inner exception.</param>
        public CustomSyntaxException(string message, Exception inner) : base(SYNTAX_ERROR_TXT + message, inner) { }

        /// <summary>
        /// Constructor of the CustomSyntaxException class.
        /// </summary>
        /// <param name="info">Stores all the data needed to serialize or deserialize an object.</param>
        /// <param name="context">Describes the source and destination of a given serialized stream, and provides an additional caller-defined context.</param>
        protected CustomSyntaxException(System.Runtime.Serialization.SerializationInfo info, System.Runtime.Serialization.StreamingContext context) : base(info, context) { }
    }
}
