﻿using Antlr4.Runtime;
using System.IO;

namespace GenLib
{
    /// <summary>
    /// Listener for syntax errors threw by ANTLR library.
    /// </summary>
    class SyntaxErrorListener : BaseErrorListener
    {
        /// <summary>
        /// This attribute contains instance of the SyntaxErrorListener class.
        /// </summary>
        private static readonly SyntaxErrorListener INSTANCE = new SyntaxErrorListener();

        /// <summary>
        /// Property of INSTANCE attribute.
        /// </summary>
        public static SyntaxErrorListener Instance
        {
            get { return INSTANCE; }
        }

        /// <summary>
        /// Upon syntax error, notify any interested parties.
        /// </summary>
        /// <param name="output">Text output.</param>
        /// <param name="recognizer">ANTLR recognizer.</param>
        /// <param name="offendingSymbol">Grammar symbol.</param>
        /// <param name="line">Line with error.</param>
        /// <param name="charPositionInLine">Char position in line with error.</param>
        /// <param name="msg">Error message.</param>
        /// <param name="e">Threw exception.</param>
        public override void SyntaxError(TextWriter output, IRecognizer recognizer, IToken offendingSymbol, int line, int charPositionInLine, string msg, RecognitionException e)
        {
            throw new AntlrSyntaxException("SYNTAX ERROR: line " + line + ":" + charPositionInLine + " " + msg);
        }

    }

}
