﻿using Antlr4.Runtime.Misc;
using GenLib.Entity;

namespace GenLib.Visitor
{
    /// <summary>
    /// This class is Visitor class for 'formal_property_or_method' rule of ANTLR grammar. It provides to create
    /// parsing tree using ANTLR interface DocsGenParserBaseVisitor.
    /// </summary>
    class FormalPropertyOrMethodVisitor : DocsGenParserBaseVisitor<Variable>
    {
        /// <summary>
        /// This method creates Variable entity and specified attributes necessary for this entity
        /// withing the parsing of 'formal_property_or_method' rule of ANTLR grammar. Then this method
        /// calls processing of 'parameters' rule of ANTLR grammar.
        /// </summary>
        /// <param name="context">Context of 'formal_property_or_method' rule.</param>
        /// <returns>New Variable entity.</returns>
        public override Variable VisitFormal_property_or_method([NotNull] DocsGenParser.Formal_property_or_methodContext context)
        {
            DocsGenParser.Property_endContext[] propertyEnds = context.property_end();
            int propertyEndsCount = propertyEnds.Length;
            Variable variable;

            if (propertyEnds[0].OPAR() != null)
            {
                variable = new Variable("this");

                if (propertyEnds[0].parameters() == null)
                {
                    variable.PropertyOrMethodList.Add(new PropertyOrMethod(context.id().GetText(), true));
                }
                else
                {
                    variable.PropertyOrMethodList.Add(new PropertyOrMethod(context.id().GetText(), new ParametersVisitor().Visit(propertyEnds[0].parameters())));
                }

                for (int i = 1; i < propertyEndsCount - 1; i++)
                {
                    if (propertyEnds[i].OPAR() != null)
                    {
                        continue;
                    }

                    if (propertyEnds[i + 1].OPAR() == null)
                    {
                        throw new CustomSyntaxException(ErrorType.FUNCTION_FOLLOWED_BY_NON_FUNCTION);
                    }
                    else
                    {
                        if (propertyEnds[i + 1].parameters() == null)
                        {
                            variable.PropertyOrMethodList.Add(new PropertyOrMethod(propertyEnds[i].ID().GetText(), true));
                        }
                        else
                        {
                            variable.PropertyOrMethodList.Add(new PropertyOrMethod(propertyEnds[i].ID().GetText(), new ParametersVisitor().Visit(propertyEnds[i + 1].parameters())));
                        }

                    }

                }

                if (propertyEnds[propertyEndsCount - 1].OPAR() == null)
                {
                    throw new CustomSyntaxException(ErrorType.OPAR_MISSING);
                }

            }
            else
            {

                string identificator = context.id().GetText();

                variable = new Variable(identificator);

                for (int i = 0; i < propertyEndsCount - 1; i++)
                {
                    if (propertyEnds[i].OPAR() != null)
                    {
                        continue;
                    }

                    if (propertyEnds[i + 1].OPAR() == null)
                    {
                        variable.PropertyOrMethodList.Add(new PropertyOrMethod(propertyEnds[i].ID().GetText()));
                    }
                    else
                    {
                        if (propertyEnds[i + 1].parameters() == null)
                        {
                            variable.PropertyOrMethodList.Add(new PropertyOrMethod(propertyEnds[i].ID().GetText(), true));
                        }
                        else
                        {
                            variable.PropertyOrMethodList.Add(new PropertyOrMethod(propertyEnds[i].ID().GetText(), new ParametersVisitor().Visit(propertyEnds[i + 1].parameters())));
                        }

                    }
                }

                if (propertyEnds[propertyEndsCount - 1].OPAR() == null)
                {
                    variable.PropertyOrMethodList.Add(new PropertyOrMethod(propertyEnds[propertyEndsCount - 1].ID().GetText()));
                }
            }

            return variable;
        }
    }
}
