﻿using Antlr4.Runtime.Misc;
using GenLib.Entity;
using System;

namespace GenLib.Visitor
{
    /// <summary>
    /// This class is Visitor class for 'parameter' rule of ANTLR grammar. It provides to create
    /// parsing tree using ANTLR interface DocsGenParserBaseVisitor.
    /// </summary>
    class ParameterVisitor : DocsGenParserBaseVisitor<Parameter>
    {
        /// <summary>
        /// This method creates Parameter entity and specified attributes necessary for this entity
        /// withing the parsing of 'parameter' rule of ANTLR grammar.
        /// </summary>
        /// <param name="context">Context of 'parameter' rule.</param>
        /// <returns>New Parameter entity.</returns>
        public override Parameter VisitParameter([NotNull] DocsGenParser.ParameterContext context)
        {
            Parameter parameter = null;

            if (context.STRING() != null)
            {
                parameter = new Parameter(context.STRING().GetText().Replace("\"", string.Empty));
            }
            else if (context.INTEGER() != null)
            {
                parameter = new Parameter(Int32.Parse(context.INTEGER().GetText()));
            }

            return parameter;
        }
    }
}
