﻿using GenLib.Document;
using System;
using System.Threading;

namespace GenTrigger
{
    /// <summary>
    /// The main class of console trigger for GenLib library.
    /// </summary>
    class Program
    {
        /// <summary>
        /// Initial point of the program. This method loads input parameters from command line 
        /// and starts document generation from document template and input data.
        /// </summary>
        /// <param name="args">Command line parameters.</param>
        static void Main(string[] args)
        {
            Thread.CurrentThread.CurrentUICulture = new System.Globalization.CultureInfo("en-US");

            if (args.Length < 3)
            {
                Console.WriteLine("Not enough arguments. Usage: <template_file> <data_file> <document_file>");
                Environment.Exit(1);
            }

            string inputFile = args[0];
            string dataFile = args[1];
            string outputFile = args[2];

            DocumentManager documentManager = DocumentManager.Instance;

            try
            {
                documentManager.LoadTempTemplateFromFile(inputFile);

                documentManager.Preprocess();

                documentManager.CreateDocument(outputFile);

                documentManager.GenerateDocument(dataFile);

                documentManager.Close();
                Console.WriteLine("Document generation successfull!");
            }
            catch(Exception e)
            {
                documentManager.Close();
                Console.WriteLine(e.Message);
                Console.WriteLine("Document generation failed!");
            }
            
            try
            {
                documentManager.CloseWordProcesses();
            }
            catch(Exception e)
            {
                Console.WriteLine("Unable to close MS Word processes: " + e.Message);
            }

            Console.ReadKey();
        }
    }
}
