﻿using System;
using System.Windows.Forms;

namespace TemplateBuilder.Forms
{
    /// <summary>
    /// This class contains global WinForms dialogs.
    /// </summary>
    public class Dialogs
    {
        /// <summary>
        /// This method shows file choose dialog for metadata JSON file.
        /// </summary>
        /// <returns>Path to the metadata file.</returns>
        public string MetadataFileChooseDialog()
        {
            string filter = "JSON|*.json";
            string title = "Select a metadata JSON file";

            return FileChooseDialog(filter, title);
        }

        /// <summary>
        /// This method shows file choose dialog for data JSON file.
        /// </summary>
        /// <returns>Path to the data file.</returns>
        public string DataFileChooseDialog()
        {
            string filter = "JSON|*.json";
            string title = "Select a data JSON file";

            return FileChooseDialog(filter, title);
        }

        /// <summary>
        /// This method shows file choose dialog for sub template DOC or DOCX file.
        /// </summary>
        /// <returns>Path to the sub template file.</returns>
        public string IncludeFileChooseDialog()
        {
            string filter = "DOCX|*.docx|DOC|*.doc";
            string title = "Select a Word document to include";

            return FileChooseDialog(filter, title);
        }

        /// <summary>
        /// This method contains general file choose dialog.
        /// </summary>
        /// <param name="filter">Suffix of the file.</param>
        /// <param name="title">Title of the file choose dialog.</param>
        /// <returns>Path to the file.</returns>
        private string FileChooseDialog(string filter, string title)
        {
            OpenFileDialog openFileDialog = new OpenFileDialog();
            openFileDialog.Filter = filter;
            openFileDialog.Title = title;

            if (openFileDialog.ShowDialog() == DialogResult.OK)
            {
                string filePath = openFileDialog.FileName;
                return filePath;
            }

            return null;
        }

        /// <summary>
        /// This method shows file save dialog for generated DOCX document.
        /// </summary>
        /// <returns>Path to the saved file.</returns>
        public string GeneratedDocSaveDialog()
        {
            SaveFileDialog saveFileDialog = new SaveFileDialog();
            saveFileDialog.Title = "Save generated Word document";
            saveFileDialog.Filter = "DOCX|*.docx|DOC|*.doc|All files (*.*)|*.*";
            saveFileDialog.FileName = "Generated Document";
            saveFileDialog.DefaultExt = "docx";
            saveFileDialog.CheckPathExists = true;
            saveFileDialog.RestoreDirectory = true;

            if (saveFileDialog.ShowDialog() == DialogResult.OK)
            {
                string filePath = saveFileDialog.FileName;

                if (filePath != null)
                {
                    
                    try
                    {
                        System.IO.FileStream fileStream = (System.IO.FileStream)saveFileDialog.OpenFile();

                        if (fileStream != null)
                        {
                            fileStream.Close();
                            return filePath;
                        }
                    }
                    catch(Exception e)
                    {
                        string errorMessage = "Unable to save file: " + e.Message;
                        MessageBox.Show(errorMessage, "Error: Unable to save file.", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    }
                }
            }

            return null;
        }
    }
}
