﻿using TemplateBuilder.Model.Entities.NodeObjects.Methods;

namespace TemplateBuilder.Model.Entities.GeneralObjects.GeneralObjectMethods
{
    /// <summary>
    /// This class represents Current Date method.
    /// </summary>
    public class GeneralObjectCurrentDateMethod
    {
        /// <summary>
        /// Prefix of the Current Date method language construction.
        /// </summary>
        private static readonly string CURRENT_DATE_MARK = "currentDate()";

        /// <summary>
        /// This attribute contains parameter of the Current Date method.
        /// </summary>
        private string parameter;

        /// <summary>
        /// Property for the 'parameter' attribute.
        /// </summary>
        private string Parameter
        {
            get
            {
                return parameter;
            }
            set
            {
                string param = value;

                parameter = param;
            }
        }

        /// <summary>
        /// Language construction of the Current Date Method to insert into document template.
        /// </summary>
        private string TemplateMark
        {
            get
            {
                string templateMark = CURRENT_DATE_MARK;

                if (!Parameter.Equals(string.Empty))
                {
                    templateMark += (new NodeObjectFormatDateMethod(Parameter)).ToString();
                }

                return templateMark;
            }
        }

        /// <summary>
        /// Constructor for the GeneralObjectCurrentDateMethod class.
        /// </summary>
        public GeneralObjectCurrentDateMethod() : this(string.Empty) { }

        /// <summary>
        /// Constructor for the GeneralObjectCurrentDateMethod class.
        /// </summary>
        /// <param name="parameter">Parameter of the Current Date method.</param>
        public GeneralObjectCurrentDateMethod(string parameter)
        {
            Parameter = parameter;
        }

        /// <summary>
        /// This method adds special characters to language construction.
        /// </summary>
        /// <param name="mark">Language construction without special characters.</param>
        /// <returns>Language construction with special characters.</returns>
        private string SetSpecialCharsToMark(string mark)
        {
            return "${" + mark + "}";
        }

        /// <summary>
        /// This method returns language construction of the Current Date method.
        /// </summary>
        /// <returns>Language construction of the Current Date method.</returns>
        public override string ToString()
        {
            return SetSpecialCharsToMark(TemplateMark);
        }
    }
}
