﻿using System.Text.RegularExpressions;

namespace TemplateBuilder.Model.Entities.NodeObjects.Directives
{
    /// <summary>
    /// This class represents tableforeach directive in metadata tree view.
    /// </summary>
    public class NodeObjectTableForeachDirective : NodeObjectDirective
    {
        /// <summary>
        /// Default value of controlling variable.
        /// </summary>
        private static readonly string DEFAULT_CONTROLLING_VARIABLE = "variable";

        /// <summary>
        /// This attribute contains controlling variable of the tableforeach directive.
        /// </summary>
        private string controllingVariable;

        /// <summary>
        /// Property for controllingVariable attribute.
        /// </summary>
        public string ControllingVariable 
        {
            get
            {
                return controllingVariable;
            } 
            private set
            {
                string variable = value;

                variable = Regex.Replace(variable, @"\s+", string.Empty);
                
                if (variable == null || variable.Equals(string.Empty))
                {
                    controllingVariable = DEFAULT_CONTROLLING_VARIABLE;
                }
                else
                {
                    controllingVariable = variable;
                }
            }
        }

        /// <summary>
        /// Full name of the node object.
        /// </summary>
        private string NodeObjectFullName { get; set; }

        /// <summary>
        /// Constructor of the NodeObjectTableForeachDirective class.
        /// </summary>
        /// <param name="controllingVariable">Controlling variable of the tableforeach directive.</param>
        /// <param name="nodeObjectFullName">Full name of the node object.</param>
        public NodeObjectTableForeachDirective(string controllingVariable, string nodeObjectFullName)
        {
            ControllingVariable = controllingVariable;
            NodeObjectFullName = nodeObjectFullName;
            DirectiveType = ENodeObjectDirectiveType.Foreach;
        }

        /// <summary>
        /// This method returns language construction of the tableforeach directive.
        /// </summary>
        /// <returns>Language construction of the tableforeach directive.</returns>
        public override string ToString()
        {
            return "#tableforeach ($" + ControllingVariable + " in $" + NodeObjectFullName + ")";
        }
    }
}
