﻿using TemplateBuilder.Model.Entities.NodeObjects.Directives;

namespace TemplateBuilder.Model.Entities.NodeObjects
{
    /// <summary>
    /// This class represents element in metadata tree view.
    /// </summary>
    public class NodeObjectElement : NodeObject
    {
        /// <summary>
        /// Directive for the current instance.
        /// </summary>
        public NodeObjectDirective Directive { get; set; }

        /// <summary>
        /// Flag: true - if descendants of this element are represented as an array; false - otherwise.
        /// </summary>
        public bool IsArray { get; private set; }

        /// <summary>
        /// Language construction of current node object to insert into document template.
        /// </summary>
        public override string TemplateMark
        {
            get
            {
                return Directive.ToString();
            }
        }

        /// <summary>
        /// Constructor of the NodeObjectElement class.
        /// </summary>
        /// <param name="nodeObjectFullName">Full name of the node object (element).</param>
        /// <param name="isArray">true - if descendants of this element are represented as an array; false - otherwise.</param>
        /// <param name="label">Label of the current element.</param>
        public NodeObjectElement(string nodeObjectFullName, bool isArray, string label) : base (nodeObjectFullName, label)
        {
            ObjectType = Metadata.ENodeObjectType.Element;
            IsArray = isArray;
        }

        /// <summary>
        /// This method adds new directive to the current instance (element).
        /// </summary>
        /// <param name="directiveType">Specific type of directive.</param>
        /// <param name="parametersStr">Parameters of the directive.</param>
        public void AddDirective(ENodeObjectDirectiveType directiveType, params string[] parametersStr)
        {
            if (directiveType.Equals(ENodeObjectDirectiveType.Foreach))
            {
                if (parametersStr.Length == 1)
                {
                    Directive = new NodeObjectForeachDirective(parametersStr[0], NodeObjectFullName);
                }
                else
                {
                    throw new AttributeException(ErrorType.INVALID_NUM_OF_ATTRS);
                }
            }
            else if (directiveType.Equals(ENodeObjectDirectiveType.TableForeach))
            {
                if (parametersStr.Length == 1)
                {
                    Directive = new NodeObjectTableForeachDirective(parametersStr[0], NodeObjectFullName);
                }
                else
                {
                    throw new AttributeException(ErrorType.INVALID_NUM_OF_ATTRS);
                }
            }
        }
    }
}
