﻿using Office = Microsoft.Office.Core;
using OfficeTools = Microsoft.Office.Tools;
using TemplateBuilder.Forms;
using TemplateBuilder.Model.Services;
using System.Threading;

namespace TemplateBuilder
{
    /// <summary>
    /// Initial point of Word Add-in. It initializes main GUI parts of this Add-in.
    /// </summary>
    public partial class ThisAddIn
    {
        /// <summary>
        /// Instance of global WinForms dialogs.
        /// </summary>
        public Dialogs Dialogs { get; set; }

        /// <summary>
        /// Instance of MetadataLoader to load metadata file.
        /// </summary>
        public MetadataLoader MetadataLoader { get; set; }

        /// <summary>
        /// WinForms Task Pane to view Metadata Tree.
        /// </summary>
        public TemplateTaskPane TemplateTaskPane { get; set; }

        /// <summary>
        /// WinForms Task Pane to view syntax errors.
        /// </summary>
        public ErrorTaskPane ErrorTaskPane { get; set; }

        /// <summary>
        /// Wrapper for TemplateTaskPane.
        /// </summary>
        public OfficeTools.CustomTaskPane CustomTaskPaneTemplate { get; set; }

        /// <summary>
        /// Wrapper for ErrorTaskPane.
        /// </summary>
        public OfficeTools.CustomTaskPane CustomTaskPaneError { get; set; }

        /// <summary>
        /// This method initializes main components of the Add-in before initialize the Add-in.
        /// </summary>
        public override void BeginInit()
        {
            Dialogs = new Dialogs();
            MetadataLoader = new MetadataLoader();
            TemplateTaskPane = new TemplateTaskPane();
            ErrorTaskPane = new ErrorTaskPane();
        }

        /// <summary>
        /// This method initializes main components of the Add-in after initialize the Add-in.
        /// </summary>
        /// <param name="sender">Sender.</param>
        /// <param name="e">Event arguments.</param>
        private void ThisAddIn_Startup(object sender, System.EventArgs e)
        {
            Thread.CurrentThread.CurrentUICulture = new System.Globalization.CultureInfo("en-US");
            CustomTaskPaneTemplate = CustomTaskPanes.Add(TemplateTaskPane, "Metadata Tree View");
            CustomTaskPaneTemplate.Width = 353;

            CustomTaskPaneError = CustomTaskPanes.Add(ErrorTaskPane, "Syntax Errors");
            CustomTaskPaneError.DockPosition = Office.MsoCTPDockPosition.msoCTPDockPositionBottom;
            CustomTaskPaneError.Height = 205;
        }

        /// <summary>
        /// This method is called immediately before the Add-in shuts down.
        /// </summary>
        /// <param name="sender">Sender.</param>
        /// <param name="e">Event arguments.</param>
        private void ThisAddIn_Shutdown(object sender, System.EventArgs e)
        {
        }

        #region VSTO generated code

        /// <summary>
        /// Required method for Designer support - do not modify
        /// the contents of this method with the code editor.
        /// </summary>
        private void InternalStartup()
        {
            this.Startup += new System.EventHandler(ThisAddIn_Startup);
            this.Shutdown += new System.EventHandler(ThisAddIn_Shutdown);
        }
        
        #endregion
    }
}
